@@ -1,5 +1,5 @@
 /*
- * Copyright 2021 Univention GmbH
+ * Copyright 2021-2022 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -26,8 +26,6 @@
  * /usr/share/common-licenses/AGPL-3; if not, see
  * <https://www.gnu.org/licenses/>.
  */
-import _ from '@/jsHelper/translate';
-import { changePassword } from '@/jsHelper/umc';
 import { randomId } from '@/jsHelper/tools';
 
 function makeEntry(entryID, availableTiles, defaultLinkTarget) {
@@ -46,31 +44,6 @@ function makeEntry(entryID, availableTiles, defaultLinkTarget) {
   };
 }
 
-function changePasswordCallback(tileClick) {
-  tileClick.$store.dispatch('navigation/setActiveButton', '');
-  tileClick.$store.dispatch('modal/setShowModalPromise', {
-    name: 'ChangePassword',
-    stubborn: true,
-  }).then((values) => {
-    changePassword(values.oldPassword, values.newPassword).then((response) => {
-      tileClick.$store.dispatch('notifications/addSuccessNotification', {
-        title: _('Change password'),
-        description: response.data.message,
-      });
-      tileClick.$store.dispatch('modal/hideAndClearModal');
-    }, (error) => {
-      console.error('Error while changing password', error);
-      tileClick.$store.dispatch('notifications/addErrorNotification', {
-        title: _('Change password'),
-      });
-      tileClick.$store.dispatch('modal/hideAndClearModal');
-      return changePasswordCallback(tileClick);
-    });
-  }, () => {
-    tileClick.$store.dispatch('modal/hideAndClearModal');
-  });
-}
-
 export default function createUserMenu(portalData) {
   if (!portalData) {
     return [];
@@ -88,19 +61,6 @@ export default function createUserMenu(portalData) {
     .map((entryID) => makeEntry(entryID, availableTiles, defaultLinkTarget))
     .filter((entry) => !!entry);
 
-  if (portalData.username) {
-    subMenuItems.unshift({
-      id: `menu-item-${randomId()}`,
-      title: {
-        en_US: 'Change password',
-        de_DE: 'Passwort ändern',
-      },
-      linkTarget: 'internalFunction',
-      internalFunction: changePasswordCallback,
-      links: [],
-    });
-  }
-
   const menuElement = {
     id: `menu-${randomId()}`,
     title: menuTitle,
