@@ -29,9 +29,11 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 #
+import asyncio
+import json
 
 import pytest
-import requests
+import tornado
 from univentionunittests import import_module
 
 
@@ -59,7 +61,7 @@ class TestUMCAuthenticator:
 		mocked_group_cache = mocker.Mock()
 		mocked_group_cache.get.return_value = {self._username.lower(): self._groups}
 		authenticator = Authenticator(self._auth_mode, self._umc_session_url, mocked_group_cache)
-		authenticator.requests_get = patch_object_module(authenticator, "requests.get")
+		authenticator.httpclient_fetch = patch_object_module(authenticator, "AsyncHTTPClient.fetch")
 		return authenticator
 
 	def test_default_init(self, dynamic_class):
@@ -81,13 +83,19 @@ class TestUMCAuthenticator:
 		cookie_mock.value = cookie
 		request_mock.cookies = {self._umc_cookie_name: cookie_mock}
 		request_mock.request.headers = {}
-		mocked_authenticator._get_username = mocker.Mock(return_value=(self._username.lower(), self._username))
+
+		async def async_magic():
+			return (self._username.lower(), self._username)
+
+		mocker.MagicMock.__await__ = lambda x: async_magic().__await__()
+		mocked_authenticator._get_username = mocker.MagicMock()
 		# Execute
-		user = mocked_authenticator.get_user(request_mock)
+		loop = asyncio.get_event_loop()
+		user = loop.run_until_complete(mocked_authenticator.get_user(request_mock))
 		mocked_authenticator._get_username.assert_called_once_with({self._umc_cookie_name: cookie})
 		assert isinstance(user, user_module.User)
 		assert user.username == self._username.lower()
-		assert user.groups == self._groups
+		assert user.groups == [x.lower() for x in self._groups]
 
 	def test_get_non_existing_user(self, mocked_authenticator, mocker, user_module):
 		# Set up
@@ -97,9 +105,15 @@ class TestUMCAuthenticator:
 		cookie_mock.value = cookie
 		request_mock.cookies = {self._umc_cookie_name: cookie_mock}
 		request_mock.request.headers = {}
-		mocked_authenticator._get_username = mocker.Mock(return_value=(None, None))
+
+		async def async_magic():
+			return (None, None)
+
+		mocker.MagicMock.__await__ = lambda x: async_magic().__await__()
+		mocked_authenticator._get_username = mocker.MagicMock()
 		# Execute
-		user = mocked_authenticator.get_user(request_mock)
+		loop = asyncio.get_event_loop()
+		user = loop.run_until_complete(mocked_authenticator.get_user(request_mock))
 		mocked_authenticator._get_username.assert_called_once_with({self._umc_cookie_name: cookie})
 		assert isinstance(user, user_module.User)
 		assert user.is_anonymous()
@@ -107,53 +121,82 @@ class TestUMCAuthenticator:
 		assert user.groups == []
 
 	def test_get_username(self, mocked_authenticator, mocker):
-		mocked_authenticator._ask_umc = mocker.Mock()
-		mocked_authenticator._ask_umc.return_value = self._username
-		assert mocked_authenticator._get_username({self._umc_cookie_name: "test_session"}) == (self._username.lower(), self._username)
-		assert mocked_authenticator._get_username({}) == (None, None)
-		mocked_authenticator._ask_umc.return_value = None
-		assert mocked_authenticator._get_username({self._umc_cookie_name: "test_session"}) == (None, None)
+		async def async_magic():
+			return self._username
+
+		async def async_magic_none():
+			return
+
+		loop = asyncio.get_event_loop()
+		mocker.MagicMock.__await__ = lambda x: async_magic().__await__()
+		mocked_authenticator._ask_umc = mocker.MagicMock()
+		assert loop.run_until_complete(mocked_authenticator._get_username({self._umc_cookie_name: "test_session"})) == (self._username.lower(), self._username)
+		assert loop.run_until_complete(mocked_authenticator._get_username({})) == (None, None)
+		mocker.MagicMock.__await__ = lambda x: async_magic_none().__await__()
+		mocked_authenticator._ask_umc = mocker.MagicMock()
+		assert loop.run_until_complete(mocked_authenticator._get_username({self._umc_cookie_name: "test_session"})) == (None, None)
 
 	def test_ask_umc_request_success(self, mocked_authenticator, mocker):
-		def _side_effect(url, cookies={}, headers={}):
+		def _side_effect(req):
 			""" Side effect to simulate successful request with different response data """
-			print("Making a request to '%s'" % url)
-			response_mock = mocker.Mock()
-			test_cookie = cookies.get(self._umc_cookie_name, "")
-			response_mock.status_code = 200
-			if test_cookie:
-				response_mock.json.return_value = {"result": {"username": self._username}}
-			else:
-				response_mock.json.return_value = {}
-			print("Received response with status 200")
-			return response_mock
+			print("Making a request to '%s'" % req.url)
 
-		mocked_authenticator.requests_get.side_effect = _side_effect
+			response_mock = mocker.Mock()
+
+			async def async_magic():
+				return response_mock
+
+			mocker.MagicMock.__await__ = lambda x: async_magic().__await__()
+			async_response_mock = mocker.MagicMock(return_value=asyncio.Future())
+			async_response_mock.return_value.set_result(response_mock)
+			test_cookie = req.headers.get('Cookie', '').split(',')
+			test_cookie = [c.strip().split('=') for c in test_cookie]
+			test_cookie = dict((k.strip(), v.strip()) for k, v in test_cookie).get(self._umc_cookie_name, "")
+			if test_cookie:
+				response_mock.body = json.dumps({"result": {"username": self._username}}).encode()
+			else:
+				response_mock.body = b'{}'
+			print("Received response with status 200")
+			return async_response_mock
+
+		mocked_authenticator.httpclient_fetch.side_effect = _side_effect
 		test_session = {self._umc_cookie_name: "test_session"}
+		loop = asyncio.get_event_loop()
+
 		# Execute with valid session expecting username to be returned
-		assert mocked_authenticator._ask_umc(test_session, {}) == self._username
-		mocked_authenticator.requests_get.assert_called_once_with(self._umc_session_url, cookies=test_session, headers={})
+		assert loop.run_until_complete(mocked_authenticator._ask_umc(test_session, {})) == self._username
+		assert mocked_authenticator.httpclient_fetch.call_count == 1
+
 		# Execute with unknown session expecting username to be None due to KeyError
-		assert mocked_authenticator._ask_umc({self._umc_cookie_name: ""}, {}) is None
-		assert mocked_authenticator.requests_get.call_count == 2
+		assert loop.run_until_complete(mocked_authenticator._ask_umc({self._umc_cookie_name: ""}, {})) is None
+		assert mocked_authenticator.httpclient_fetch.call_count == 2
 
 	def test_ask_umc_request_error(self, mocked_authenticator, mocker):
-		def _side_effect(url, cookies={}, headers={}):
+		def _side_effect(req):
 			""" Side effect to simulate request with a http error """
-			print("Making a request to '%s'" % url)
+			print("Making a request to '%s'" % req.url)
 			response_mock = mocker.Mock()
 			response_mock.status_code = 404
-			response_mock.json.side_effect = ValueError
-			print("Received response with status 404")
-			return response_mock
+			response_mock.body.decode.return_value = b'X'
 
-		mocked_authenticator.requests_get.side_effect = _side_effect
+			async def async_magic():
+				return response_mock
+
+			mocker.MagicMock.__await__ = lambda x: async_magic().__await__()
+			async_response_mock = mocker.MagicMock(return_value=asyncio.Future())
+			async_response_mock.return_value.set_result(response_mock)
+			print("Received response with status 404")
+			return async_response_mock
+
+		loop = asyncio.get_event_loop()
+
+		mocked_authenticator.httpclient_fetch.side_effect = _side_effect
 		test_session = {self._umc_cookie_name: "test_session"}
 		# Execute while expecting a catched internal ValueError
-		assert mocked_authenticator._ask_umc(test_session, {}) is None
-		mocked_authenticator.requests_get.assert_called_once_with(self._umc_session_url, cookies=test_session, headers={})
+		assert loop.run_until_complete(mocked_authenticator._ask_umc(test_session, {})) is None
+		assert mocked_authenticator.httpclient_fetch.call_count == 1
 		# Execute while expecting catched internal RequestException
-		mocked_authenticator.requests_get.side_effect = [requests.exceptions.ConnectionError, requests.exceptions.MissingSchema]
-		assert mocked_authenticator._ask_umc(test_session, {}) is None
-		assert mocked_authenticator._ask_umc(test_session, {}) is None
-		assert mocked_authenticator.requests_get.call_count == 3
+		mocked_authenticator.httpclient_fetch.side_effect = [tornado.httpclient.HTTPError(404), IOError]
+		assert loop.run_until_complete(mocked_authenticator._ask_umc(test_session, {})) is None
+		assert loop.run_until_complete(mocked_authenticator._ask_umc(test_session, {})) is None
+		assert mocked_authenticator.httpclient_fetch.call_count == 3
